<?php

namespace Schaffen\Gef\Http\Controllers;

use App\Http\Controllers\Controller;
use App\Http\Utils\Response;
use Illuminate\Http\Request;

use Schaffen\Gef\Http\Requests;
use Prettus\Service\Contracts\ServiceInterface;
use Prettus\Service\Exceptions\ServiceException;
use Schaffen\Gef\Http\Requests\AgendamentoVeiculoUsoCreateRequest;
use Schaffen\Gef\Http\Requests\AgendamentoVeiculoUsoUpdateRequest;
use Schaffen\Gef\Models\AgendamentoVeiculoUso;
use Schaffen\Gef\Repositories\AgendamentoVeiculoUsoRepository;
use Schaffen\Gef\Services\AgendamentoVeiculoUsoService;

/**
 * Class AgendamentoVeiculoUsosController.
 *
 * @package namespace Schaffen\Gef\Http\Controllers;
 */
class AgendamentoVeiculoUsosController extends Controller
{
    /**
     * @var AgendamentoVeiculoUsoRepository
     */
    protected $repository;

    /**
     * @var AgendamentoVeiculoUsoService
     */
    protected $service;

    /**
     * AgendamentoVeiculoUsosController constructor.
     *
     * @param AgendamentoVeiculoUsoRepository $repository
     * @param AgendamentoVeiculoUsoService $service
     */
    public function __construct(AgendamentoVeiculoUsoRepository $repository, AgendamentoVeiculoUsoService $service)
    {
        $this->repository = $repository;
        $this->service  = $service;
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {

       $this->repository->pushCriteria(new \Schaffen\Gef\Criterias\RequestPrefixCriteria($request, AgendamentoVeiculoUso::$prefix));
       $agendamento_veiculo_uso = $this->repository->all();


       return Response::response(true,null, $agendamento_veiculo_uso['data'],null);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  AgendamentoVeiculoUsoCreateRequest $request
     *
     * @return \Illuminate\Http\Response
     *
     * @throws \Prettus\Service\Exceptions\ServiceException
     */
    public function store(AgendamentoVeiculoUsoCreateRequest $request)
    {
       $response = $this->service->updateOrCreate($request->all());
       return Response::response($response['status'],$response['message'], $response['data'],$response['errors'], $response['http_code']);
    }

    /**
     * Display the specified resource.
     *
     * @param  int $id
     *
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
       $this->repository->setPresenter("Schaffen\\Gef\\Presenters\\AgendamentoVeiculoUsoShowPresenter");
       $agendamento_veiculo_uso = $this->repository->find($id);

       return Response::response(true,null, $agendamento_veiculo_uso['data'],null);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int $id
     *
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $agendamentoVeiculoUso = $this->repository->find($id);

        return view('agendamentoVeiculoUsos.edit', compact('agendamentoVeiculoUso'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  AgendamentoVeiculoUsoUpdateRequest $request
     * @param  string            $id
     *
     * @return Response
     *
     * @throws \Prettus\Service\Exceptions\ServiceException
     */
    public function update(AgendamentoVeiculoUsoUpdateRequest $request, $id)
    {
       $response = $this->service->updateOrCreate($request->all(), $id);
       return Response::response($response['status'],$response['message'], $response['data'],$response['errors'], $response['http_code']);
    }


    /**
     * Remove the specified resource from storage.
     *
     * @param  int $id
     *
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $deleted = $this->repository->delete($id);

        if (request()->wantsJson()) {

            return response()->json([
                'message' => 'AgendamentoVeiculoUso deleted.',
                'deleted' => $deleted,
            ]);
        }

        return redirect()->back()->with('message', 'AgendamentoVeiculoUso deleted.');
    }
}
